<?php

//Setup -------------
if (! function_exists('bonyo_setup')) :
function bonyo_setup() {

	load_theme_textdomain('bonyo', get_template_directory() . '/languages');

	add_theme_support('post-thumbnails');
	add_theme_support('html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption'));
	add_theme_support("title-tag");
	add_theme_support('automatic-feed-links');

	//disable widget block editor
	remove_theme_support( 'widgets-block-editor' );

	//Content Width
	$GLOBALS['content_width'] = apply_filters('bny_content_width', 624);

	//3 menus
	register_nav_menus( array(
		'global' => 'Nav Menu 1',
		'header' => 'Nav Menu 2',
	));
}
endif;
add_action('after_setup_theme', 'bonyo_setup');


	
//Load Styles and Scripts -------------
function bny_enq_style_scripts() {
	global $template;

	//style of theme
	if (get_theme_mod('ck_css', false)) {
		wp_dequeue_style( 'theme-style' );
	} else {
		wp_enqueue_style('theme-style', get_stylesheet_directory_uri() . '/style.min.css');
	}
	//Font Awesome 4.7.0
	wp_enqueue_style('fontawesome-style', get_stylesheet_directory_uri() . '/fonts/font-awesome-4.7.0/css/font-awesome.min.css');

	//Comment Reply
	if (is_singular() && comments_open()) {
		wp_enqueue_script('comment-reply');
	}

	//Disable Style for block editor (Gutenberg)
	wp_dequeue_style( 'wp-block-library' );
	wp_dequeue_style( 'wp-block-library' );
	wp_dequeue_style( 'wp-block-library-theme' );
	wp_dequeue_style( 'global-styles' ); // theme.json

	//Remove comment-reply.min.js
	wp_deregister_script('comment-reply');
}
add_action('wp_enqueue_scripts', 'bny_enq_style_scripts');


//Remove global CSS (from WordPress 6.0)
function custom_wp_remove_global_css() {
   remove_action( 'wp_enqueue_scripts', 'wp_enqueue_global_styles' );
   remove_action( 'wp_body_open', 'wp_global_styles_render_svg_filters' );
}
add_action( 'init', 'custom_wp_remove_global_css' );


//replace style meta tag --------------
function bny_css_async($tag) {
	if (!strpos($tag, 'fontawesome-style') === false) {
		$awesome = get_template_directory_uri() . '/fonts/font-awesome-4.7.0/css/font-awesome.min.css';
		$tag = str_replace('media=\'all\' />', 'media="none" onload="if(media!=\'all\')media=\'all\'"><noscript><link rel="stylesheet" href="' . $awesome . '"></noscript>', $tag);
	}
	return $tag;
}
add_filter('style_loader_tag', 'bny_css_async');


//noindex
function bny_wp_head_noindex() {
	$noidx = '<meta name="robots" content="noindex" />' . "\n";
	if ( is_search() || is_404() ) {
		echo $noidx;
	}
}
add_action('wp_head', 'bny_wp_head_noindex');


//Sidebar Widget -------------
if (!function_exists('bonyo_widgets_init')) {
	function bonyo_widgets_init() {
		register_sidebar(array(
			'name'          => esc_html__('1st Sidebar', 'bonyo'),
			'id'            => 'sidebar-1',
			'description'   => esc_html__('1st Sidebar', 'bonyo'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		));
//2ܤΥɥС (2ndơޤͭ)
//		register_sidebar(array(
//			'name'          => esc_html__('2nd Sidebar', 'bonyo'),
//			'id'            => 'sidebar-2',
//			'description'   => esc_html__('2nd Sidebar.', 'bonyo'),
//			'before_widget' => '<section id="%1$s" class="widget %2$s">',
//			'after_widget'  => '</section>',
//			'before_title'  => '<h3 class="widget-title">',
//			'after_title'   => '</h3>',
//		));
	}
}
add_action('widgets_init', 'bonyo_widgets_init');



//Search widget form ---------------
function bny_search_form($form) {
	$form = '<form role="search" method="get" class="search-form" action="' . esc_url(home_url('/')) . '">
	<label>
		<span class="screen-reader-text">Search:</span>
		<input type="search" class="search-field" placeholder="" value="" name="s" />
	</label>
	<input type="submit" class="search-submit" value="&#xf002;" />
	</form>' . "\n";
	return $form;
}
add_filter('get_search_form', 'bny_search_form');


// 3 articles in front page
function my_pre_get_posts($query) {
        if ($query->is_main_query() && !is_admin()) {
                if (is_home() || is_front_page()) {
                        $query->set('posts_per_page', 3);
                }
        }
}
add_action('pre_get_posts', 'my_pre_get_posts');


//Remove inline style from tagcloud widget
function remove_tagcloud_inline_css($input){ 
        return preg_replace('/ style=("|\')(.*?)("|\')/','',$input); 
}
add_filter('wp_generate_tag_cloud', 'remove_tagcloud_inline_css',10,1);



////Remove Action -------------
remove_action('wp_head', 'wp_generator');					//Remove "WordPress Version" meta tag.
remove_action('wp_head', 'rsd_link');						//Removeg "RSD(Really Simple Discovery)" meta tag.
remove_action('wp_head', 'wlwmanifest_link');				//Remove "Windows Live Writer link" meta tag.
remove_action('wp_head', 'rest_output_link_wp_head');		//Remove "REST API endpoint" 
remove_action('wp_head', 'wp_shortlink_wp_head');
remove_action('wp_head', 'feed_links', 2);
remove_action('wp_head', 'feed_links_extra', 3);
remove_action('wp_head', 'rest_output_link_wp_head');		//Remove "REST API endpoint" 
remove_action('wp_head', 'wp_oembed_add_discovery_links');	//Remove "oEmbed links"
remove_action('wp_head', 'wp_oembed_add_host_js');			//Remove "oEmbed JS"
remove_action('wp_head', 'print_emoji_detection_script', 7);//Remove Emoji Script
remove_action('wp_print_styles', 'print_emoji_styles');		//Remove Emoji style

remove_filter('the_content', 'wpautop');					//ư<p>դΤ޻
remove_filter('the_content', 'wptexturize');				//wptexturizeˤʸѴ򤷤ʤ
remove_filter('the_content', 'convert_chars');				//convert_charsˤʸѴ򤷤ʤ
remove_filter('the_title', 'wpautop');						//Ს
remove_filter('the_title', 'wptexturize');					//Ს

//Remove from comment feed
function comment_feed_remove() {
	if ( is_comment_feed() ) {
		remove_action('do_feed_rdf', 'do_feed_rdf');
		remove_action('do_feed_rss', 'do_feed_rss');
		remove_action('do_feed_rss2', 'do_feed_rss2');
		remove_action('do_feed_atom', 'do_feed_atom');
	}
}
add_action('parse_query', 'comment_feed_remove');
remove_filter('wp_head', 'feed_links', 2);
remove_action('wp_head', 'feed_links_extra', 3);


///Disable Rest API
remove_action('template_redirect', 'rest_output_link_header', 11 );

///Disable block editor (Gutenberg Editor) ------------
add_filter('use_block_editor_for_post', '__return_false');

///Disable auto texturize 
add_filter('run_wptexturize', '__return_false');

//Extra -------------

//Minify CSS when logging out
function run_at_logout(){
	locate_template('inc/extra-functions.php', true);
	exec_css_minimization();
	if (get_theme_mod('ck_sidebar', false)) {
		bny_static_sidebar(1);        // <- 1 is 'sidebar-1'
	//	bny_static_sidebar(2);        // <- 2 is 'sidebar-2'
	}
}
add_action('wp_logout', 'run_at_logout');

//Customizer
locate_template('inc/bny-customizer.php', true);

